@@ -33,23 +33,39 @@
 #' \item{safety_prob}{probability next score safety this half.}
 #' \item{td_prob}{probability text score touchdown this half.}
 #' }
-#' @importFrom rlang .data
-#' @importFrom dplyr select mutate bind_cols
-#' @importFrom tidyselect any_of
-#' @importFrom stats predict
 #' @export
+#' @examples
+#' \donttest{
+#' library(dplyr)
+#' data <- tibble::tibble(
+#' "season" = 1999:2019,
+#' "home_team" = "SEA",
+#' "posteam" = "SEA",
+#' "roof" = "outdoors",
+#' "half_seconds_remaining" = 1800,
+#' "yardline_100" = c(rep(80, 17), rep(75, 4)),
+#' "down" = 1,
+#' "ydstogo" = 10,
+#' "posteam_timeouts_remaining" = 3,
+#' "defteam_timeouts_remaining" = 3
+#' )
+#'
+#' nflfastR::calculate_expected_points(data) %>%
+#'   dplyr::select(season, yardline_100, td_prob, ep)
+#' }
 calculate_expected_points <- function(pbp_data) {
+
+   # drop existing values of ep and the probs before making new ones
+  pbp_data <- pbp_data %>% dplyr::select(-tidyselect::any_of(drop.cols))
+
   suppressWarnings(
     model_data <- pbp_data %>%
-      # drop existing values of ep and the probs before making new ones
-      dplyr::select(-any_of(drop.cols)) %>%
       make_model_mutations() %>%
       ep_model_select()
   )
 
-
   preds <- as.data.frame(
-    matrix(stats::predict(ep_model, as.matrix(model_data)), ncol = 7, byrow = TRUE)
+    matrix(stats::predict(fastrmodels::ep_model, as.matrix(model_data)), ncol = 7, byrow = TRUE)
   )
 
   colnames(preds) <- c(
@@ -84,18 +100,17 @@ drop.cols <- c(
 #' for provided plays. Returns the data with
 #' probabilities of winning the game. The following columns
 #' must be present: receive_h2_ko (1 if game is in 1st half and possession
-#' team will receive 2nd half kickoff, 0 otherwise), ep (expected points),
+#' team will receive 2nd half kickoff, 0 otherwise),
 #' home_team, posteam, half_seconds_remaining, game_seconds_remaining,
 #' spread_line (how many points home team was favored by), down, ydstogo,
 #' yardline_100, posteam_timeouts_remaining, defteam_timeouts_remaining
 #'
 #' @param pbp_data Play-by-play dataset to estimate win probability for.
 #' @details Computes win probability for provided plays. Returns the data with
-#' probabilities of each scoring event and EP added. The following columns
+#' spread and non-spread-adjusted win probabilities. The following columns
 #' must be present:
 #' \itemize{
 #' \item{receive_2h_ko (1 if game is in 1st half and possession team will receive 2nd half kickoff, 0 otherwise)}
-#' \item{ep (expected points)}
 #' \item{score_differential}
 #' \item{home_team}
 #' \item{posteam}
@@ -113,24 +128,41 @@ drop.cols <- c(
 #' \item{wp}{win probability.}
 #' \item{vegas_wp}{win probability taking into account pre-game spread.}
 #' }
-#' @importFrom rlang .data
-#' @importFrom dplyr select mutate if_else rename bind_cols
-#' @importFrom tidyselect any_of
-#' @importFrom stats predict
-#' @importFrom tibble as_tibble
 #' @export
+#' @examples
+#' \donttest{
+#' library(dplyr)
+#' data <- tibble::tibble(
+#' "receive_2h_ko" = 0,
+#' "home_team" = "SEA",
+#' "posteam" = "SEA",
+#' "score_differential" = 0,
+#' "half_seconds_remaining" = 1800,
+#' "game_seconds_remaining" = 3600,
+#' "spread_line" = c(1, 3, 4, 7, 14),
+#' "down" = 1,
+#' "ydstogo" = 10,
+#' "yardline_100" = 75,
+#' "posteam_timeouts_remaining" = 3,
+#' "defteam_timeouts_remaining" = 3
+#' )
+#'
+#' nflfastR::calculate_win_probability(data) %>%
+#'   dplyr::select(spread_line, wp, vegas_wp)
+#' }
 calculate_win_probability <- function(pbp_data) {
+
+  # drop existing values of ep and the probs before making new ones
+  pbp_data <- pbp_data %>% dplyr::select(-tidyselect::any_of(drop.cols.wp))
+
   suppressWarnings(
     model_data <- pbp_data %>%
-      # drop existing values of ep and the probs before making new ones
-      dplyr::select(-any_of(drop.cols.wp)) %>%
       dplyr::mutate(
         home = dplyr::if_else(.data$posteam == .data$home_team, 1, 0),
-        ExpScoreDiff = .data$ep + .data$score_differential,
         posteam_spread = dplyr::if_else(.data$home == 1, .data$spread_line, -1 * .data$spread_line),
         elapsed_share = (3600 - .data$game_seconds_remaining) / 3600,
         spread_time = .data$posteam_spread * exp(-4 * .data$elapsed_share),
-        ExpScoreDiff_Time_Ratio = .data$ExpScoreDiff / (.data$game_seconds_remaining + 1)
+        Diff_Time_Ratio = .data$score_differential / (exp(-4 * .data$elapsed_share))
       )
   )
 
