@@ -42,22 +42,23 @@
 #' \item{fantasy_player_id}{ID of the rusher on rush plays or receiver on pass plays (from official stats).}
 #' \item{jersey_number}{Jersey number of the player listed in the 'name' column.}
 #' \item{id}{ID of the player in the 'name' column.}
-#' \item{qb_epa}{Gives QB credit for EPA for up to the point where a receiver lost a fumble after a completed catch and makes EPA work more like passing yards on plays with fumbles.}
-#' \item{out_of_bounds}{1 if play description contains ran ob, pushed ob, or sacked ob; 0 otherwise.}
+#' \item{out_of_bounds}{= 1 if play description contains "ran ob", "pushed ob", or "sacked ob"; = 0 otherwise.}
+#' \item{home_opening_kickoff}{= 1 if the home team received the opening kickoff, 0 otherwise.}
 #' }
 #' @export
 clean_pbp <- function(pbp, ...) {
   if (nrow(pbp) == 0) {
-    usethis::ui_info("Nothing to clean. Return passed data frame.")
+    user_message("Nothing to clean. Return passed data frame.", "info")
     r <- pbp
   } else{
-    usethis::ui_todo("Cleaning up play-by-play...")
+    user_message("Cleaning up play-by-play...", "todo")
 
     # drop existing values of clean_pbp
     pbp <- pbp %>% dplyr::select(-tidyselect::any_of(drop.cols))
 
     r <- pbp %>%
       dplyr::mutate(
+        aborted_play = dplyr::if_else(stringr::str_detect(.data$desc, 'Aborted'), 1, 0),
         #get rid of extraneous spaces that mess with player name finding
         #if there is a space or dash, and then a capital letter, and then a period, and then a space, take out the space
         desc = stringr::str_replace_all(.data$desc, "(((\\s)|(\\-))[A-Z]\\.)\\s+", "\\1"),
@@ -86,24 +87,30 @@ clean_pbp <- function(pbp, ...) {
           stringr::str_detect(.data$desc, glue::glue('{abnormal_play}')) ~ .data$passer_player_name,
           TRUE ~ .data$passer
         ),
-        #finally, for rusher, if there was already a passer (eg from scramble), set rusher to NA
+        # fix the plays where scramble was fixed using charting data in 2005
+        passer = dplyr::case_when(
+          is.na(.data$passer) & .data$qb_scramble == 1 & !is.na(.data$rusher) & .data$season == 2005 ~ .data$rusher,
+          TRUE ~ .data$passer
+        ),
+        # finally, for rusher, if there was already a passer (eg from scramble), set rusher to NA
         rusher = dplyr::if_else(
           !is.na(.data$passer), NA_character_, .data$rusher
         ),
-        #if no pass is thrown, there shouldn't be a receiver
+        # if no pass is thrown, there shouldn't be a receiver
         receiver = dplyr::if_else(
           stringr::str_detect(.data$desc, ' pass '), .data$receiver, NA_character_
         ),
         # if there's a pass, sack, or scramble, it's a pass play...
-        pass = dplyr::if_else(stringr::str_detect(.data$desc, "( pass )|(sacked)|(scramble)"), 1, 0),
+        pass = dplyr::if_else(stringr::str_detect(.data$desc, "( pass )|(sacked)|(scramble)") | .data$qb_scramble == 1, 1, 0),
         # ...unless it says "backwards pass" and there's a rusher
         pass = dplyr::if_else(
           stringr::str_detect(.data$desc, "(backward pass)|(Backward pass)") & !is.na(.data$rusher),
           0, .data$pass
           ),
         # and make sure there's no pass on a kickoff (sometimes there's forward pass on kickoff but that's not a pass play)
-        pass = dplyr::if_else(
-          .data$kickoff_attempt == 1, 0, .data$pass
+        pass = dplyr::case_when(
+          .data$kickoff_attempt == 1 ~ 0,
+          TRUE ~ .data$pass
         ),
         #if there's a rusher and it wasn't a QB kneel or pass play, it's a run play
         rush = dplyr::if_else(!is.na(.data$rusher) & .data$qb_kneel == 0 & .data$pass == 0, 1, 0),
@@ -126,6 +133,8 @@ clean_pbp <- function(pbp, ...) {
           TRUE ~ .data$passer
         ),
         rusher = dplyr::case_when(
+          rusher == "D.Johnson" & posteam == "HOU" & season == 2020 & rusher_jersey_number == 31 ~ "Da.Johnson",
+          rusher == "D.Johnson" & posteam == "HOU" & season == 2020 & rusher_jersey_number == 25 ~ "Du.Johnson",
           rusher == "Jos.Allen" ~ "J.Allen",
           rusher == "Alex Smith" | rusher == "Ale.Smith" ~ "A.Smith",
           rusher == "Ryan" & .data$posteam == "ATL" ~ "M.Ryan",
@@ -147,7 +156,6 @@ clean_pbp <- function(pbp, ...) {
           TRUE ~ receiver
         ),
         first_down = dplyr::if_else(.data$first_down_rush == 1 | .data$first_down_pass == 1 | .data$first_down_penalty == 1, 1, 0),
-        aborted_play = dplyr::if_else(stringr::str_detect(.data$desc, 'Aborted'), 1, 0),
         # easy filter: play is 1 if a "special teams" play, or 0 otherwise
         # with thanks to Lee Sharpe for the code
         special = dplyr::if_else(.data$play_type %in%
@@ -165,6 +173,7 @@ clean_pbp <- function(pbp, ...) {
         "side_of_field", "forced_fumble_player_1_team", "forced_fumble_player_2_team",
         "solo_tackle_1_team", "solo_tackle_2_team",
         "assist_tackle_1_team", "assist_tackle_2_team", "assist_tackle_3_team", "assist_tackle_4_team",
+        "tackle_with_assist_1_team", "tackle_with_assist_2_team",
         "fumbled_1_team", "fumbled_2_team", "fumble_recovery_1_team", "fumble_recovery_2_team",
         "yrdln", "end_yard_line", "drive_start_yard_line", "drive_end_yard_line"
       ), team_name_fn) %>%
@@ -174,8 +183,7 @@ clean_pbp <- function(pbp, ...) {
 
       dplyr::group_by(.data$passer, .data$posteam, .data$season) %>%
       dplyr::mutate(
-        passer_id = dplyr::if_else(is.na(.data$passer), NA_character_, custom_mode(.data$passer_player_id)),
-        passer_jersey_number = dplyr::if_else(is.na(.data$passer), NA_integer_, custom_mode(.data$passer_jersey_number))
+        passer_id = dplyr::if_else(is.na(.data$passer), NA_character_, custom_mode(.data$passer_player_id))
       ) %>%
 
       dplyr::group_by(.data$passer_id) %>%
@@ -183,8 +191,7 @@ clean_pbp <- function(pbp, ...) {
 
       dplyr::group_by(.data$rusher, .data$posteam, .data$season) %>%
       dplyr::mutate(
-        rusher_id = dplyr::if_else(is.na(.data$rusher), NA_character_, custom_mode(.data$rusher_player_id)),
-        rusher_jersey_number = dplyr::if_else(is.na(.data$rusher), NA_integer_, custom_mode(.data$rusher_jersey_number))
+        rusher_id = dplyr::if_else(is.na(.data$rusher), NA_character_, custom_mode(.data$rusher_player_id))
       ) %>%
 
       dplyr::group_by(.data$rusher_id) %>%
@@ -192,8 +199,7 @@ clean_pbp <- function(pbp, ...) {
 
       dplyr::group_by(.data$receiver, .data$posteam, .data$season) %>%
       dplyr::mutate(
-        receiver_id = dplyr::if_else(is.na(.data$receiver), NA_character_, custom_mode(.data$receiver_player_id)),
-        receiver_jersey_number = dplyr::if_else(is.na(.data$receiver), NA_integer_, custom_mode(.data$receiver_jersey_number))
+        receiver_id = dplyr::if_else(is.na(.data$receiver), NA_character_, custom_mode(.data$receiver_player_id))
       ) %>%
 
       dplyr::group_by(.data$receiver_id) %>%
@@ -201,6 +207,18 @@ clean_pbp <- function(pbp, ...) {
 
       dplyr::ungroup() %>%
       dplyr::mutate(
+        # if there's an aborted snap and qb didn't get a pass off,
+        # then charge it to whoever charged with the fumble
+        # this has to go after all the custom_mode stuff or it gets messed up
+        rusher = dplyr::if_else(
+          .data$aborted_play == 1 & is.na(.data$passer) & !is.na(.data$fumbled_1_player_name),
+          .data$fumbled_1_player_name, .data$rusher
+        ),
+        rusher_id = dplyr::if_else(
+          .data$aborted_play == 1 & is.na(.data$passer) & !is.na(.data$fumbled_1_player_id),
+          .data$fumbled_1_player_id, .data$rusher_id
+        ),
+
         name = dplyr::if_else(!is.na(.data$passer), .data$passer, .data$rusher),
         jersey_number = dplyr::if_else(!is.na(.data$passer_jersey_number), .data$passer_jersey_number, .data$rusher_jersey_number),
         id = dplyr::if_else(!is.na(.data$passer_id), .data$passer_id, .data$rusher_id)
@@ -234,7 +252,13 @@ clean_pbp <- function(pbp, ...) {
         out_of_bounds = dplyr::if_else(
           stringr::str_detect(.data$desc, "(ran ob)|(pushed ob)|(sacked ob)"), 1, 0
         )
-      )
+      ) %>%
+      dplyr::group_by(.data$game_id) %>%
+      dplyr::mutate(
+        home_opening_kickoff = dplyr::if_else(.data$home_team == dplyr::first(stats::na.omit(.data$posteam)), 1, 0)
+      ) %>%
+      dplyr::ungroup()
+
   }
 
   message_completed("Cleaning completed", ...)
@@ -245,11 +269,11 @@ clean_pbp <- function(pbp, ...) {
 #these things are used in clean_pbp() above
 
 # look for First[period or space]Last[maybe - or ' in last][maybe more letters in last][maybe Jr. or II or IV]
-big_parser <- "(?<=)[A-Z][A-z]*(\\.|\\s)+[A-Z][A-z]*\\'*\\-*[A-Z]*[a-z]*(\\s((Jr.)|(Sr.)|I{2,3})|(IV))?"
+big_parser <- "(?<=)[A-Z][A-z]*+(\\.|\\s)+[A-Z][A-z]*+\\'*\\-*[A-Z]*+[a-z]*+(\\s((Jr.)|(Sr.)|I{2,3})|(IV))?"
 # maybe some spaces and letters, and then a rush direction unless they fumbled
-rush_finder <- "(?=\\s*[a-z]*\\s*((FUMBLES) | (left end)|(left tackle)|(left guard)|(up the middle)|(right guard)|(right tackle)|(right end)))"
+rush_finder <- "(?=\\s*[a-z]*+\\s*((FUMBLES) | (left end)|(left tackle)|(left guard)|(up the middle)|(right guard)|(right tackle)|(right end)))"
 # maybe some spaces and leters, and then pass / sack / scramble
-pass_finder <- "(?=\\s*[a-z]*\\s*(( pass)|(sack)|(scramble)))"
+pass_finder <- "(?=\\s*[a-z]*+\\s*(( pass)|(sack)|(scramble)))"
 # to or for, maybe a jersey number and a dash
 receiver_finder <- "(?<=((to)|(for))\\s[:digit:]{0,2}\\-{0,1})"
 # weird play finder
@@ -265,7 +289,8 @@ drop.cols <- c(
   "success", "passer", "rusher", "receiver", "pass", "rush", "special",
   "first_down", "play", "passer_id", "rusher_id", "receiver_id", "name", "id",
   "passer_jersey_number", "rusher_jersey_number", "receiver_jersey_number",
-  "jersey_number"
+  "jersey_number", "aborted_play", "fantasy", "fantasy_id", "fantasy_player_name",
+  "fantasy_player_id", "out_of_bounds"
 )
 
 # fixes team names on columns with yard line
@@ -299,7 +324,7 @@ team_name_fn <- function(var) {
 add_qb_epa <- function(pbp, ...) {
 
   if (nrow(pbp) == 0) {
-    usethis::ui_info("Nothing to do. Return passed data frame.")
+    user_message("Nothing to do. Return passed data frame.", "info")
   } else {
     # drop existing values of clean_pbp
     pbp <- pbp %>% dplyr::select(-tidyselect::any_of("qb_epa"))
