@@ -34,7 +34,7 @@ nflscrapr_cols <-
     "desc", "play_type", "yards_gained", "shotgun", "no_huddle", "qb_dropback", "qb_kneel", "qb_spike",
     "qb_scramble", "pass_length", "pass_location", "air_yards", "yards_after_catch",
     "run_location", "run_gap", "field_goal_result", "kick_distance", "extra_point_result", "two_point_conv_result",
-    "home_timeouts_remaining", "away_timeouts_remaining", "timeout", "timeout_team", "td_team",
+    "home_timeouts_remaining", "away_timeouts_remaining", "timeout", "timeout_team", "td_team", "td_player_name", "td_player_id",
     "posteam_timeouts_remaining", "defteam_timeouts_remaining",
     "total_home_score", "total_away_score", "posteam_score",
     "defteam_score", "score_differential", "posteam_score_post",
@@ -104,8 +104,11 @@ nflscrapr_cols <-
     "fumbled_2_player_name", "fumbled_2_team", "fumble_recovery_1_team",
     "fumble_recovery_1_yards", "fumble_recovery_1_player_id", "fumble_recovery_1_player_name",
     "fumble_recovery_2_team", "fumble_recovery_2_yards", "fumble_recovery_2_player_id",
-    "fumble_recovery_2_player_name", "return_team",
-    "return_yards", "penalty_team", "penalty_player_id",
+    "fumble_recovery_2_player_name",
+    #new in nflfastR v4.1
+    "sack_player_id", "sack_player_name", "half_sack_1_player_id", "half_sack_1_player_name",
+    "half_sack_2_player_id", "half_sack_2_player_name",
+    "return_team", "return_yards", "penalty_team", "penalty_player_id",
     "penalty_player_name", "penalty_yards", "replay_or_challenge",
     "replay_or_challenge_result", "penalty_type",
     "defensive_two_point_attempt",
