@@ -79,6 +79,8 @@
 #' \item{timeout}{Binary indicator for whether or not a timeout was called by either team.}
 #' \item{timeout_team}{String abbreviation for which team called the timeout.}
 #' \item{td_team}{String abbreviation for which team scored the touchdown.}
+#' \item{td_player_name}{String name of the player who scored a touchdown.}
+#' \item{td_player_id}{Unique identifier of the player who scored a touchdown.}
 #' \item{posteam_timeouts_remaining}{Number of timeouts remaining for the possession team.}
 #' \item{defteam_timeouts_remaining}{Number of timeouts remaining for the team on defense.}
 #' \item{total_home_score}{Score for the home team at the start of the play.}
@@ -250,10 +252,10 @@
 #' \item{tackle_for_loss_1_player_name}{String name for one of the potential players with the tackle for loss.}
 #' \item{tackle_for_loss_2_player_id}{Unique identifier for one of the potential players with the tackle for loss.}
 #' \item{tackle_for_loss_2_player_name}{String name for one of the potential players with the tackle for loss.}
-#' \item{qb_hit_1_player_id}{Unique identifier for one of the potential players that hit the QB.}
-#' \item{qb_hit_1_player_name}{String name for one of the potential players that hit the QB.}
-#' \item{qb_hit_2_player_id}{Unique identifier for one of the potential players that hit the QB.}
-#' \item{qb_hit_2_player_name}{String name for one of the potential players that hit the QB.}
+#' \item{qb_hit_1_player_id}{Unique identifier for one of the potential players that hit the QB. No sack as the QB was not the ball carrier. For sacks please see `sack_player` or `half_sack_*_player`.}
+#' \item{qb_hit_1_player_name}{String name for one of the potential players that hit the QB. No sack as the QB was not the ball carrier. For sacks please see `sack_player` or `half_sack_*_player`.}
+#' \item{qb_hit_2_player_id}{Unique identifier for one of the potential players that hit the QB. No sack as the QB was not the ball carrier. For sacks please see `sack_player` or `half_sack_*_player`.}
+#' \item{qb_hit_2_player_name}{String name for one of the potential players that hit the QB. No sack as the QB was not the ball carrier. For sacks please see `sack_player` or `half_sack_*_player`.}
 #' \item{forced_fumble_player_1_team}{Team of one of the players with a forced fumble.}
 #' \item{forced_fumble_player_1_player_id}{Unique identifier of one of the players with a forced fumble.}
 #' \item{forced_fumble_player_1_player_name}{String name of one of the players with a forced fumble.}
@@ -303,6 +305,12 @@
 #' \item{fumble_recovery_2_yards}{Yards gained by one of the players with a fumble recovery.}
 #' \item{fumble_recovery_2_player_id}{Unique identifier of one of the players with a fumble recovery.}
 #' \item{fumble_recovery_2_player_name}{String name of one of the players with a fumble recovery.}
+#' \item{sack_player_id}{Unique identifier of the player who recorded a solo sack.}
+#' \item{sack_player_name}{String name of the player who recorded a solo sack.}
+#' \item{half_sack_1_player_id}{Unique identifier of the first player who recorded half a sack.}
+#' \item{half_sack_1_player_name}{String name of the first player who recorded half a sack.}
+#' \item{half_sack_2_player_id}{Unique identifier of the second player who recorded half a sack.}
+#' \item{half_sack_2_player_name}{String name of the second player who recorded half a sack.}
 #' \item{return_team}{String abbreviation of the return team.}
 #' \item{return_yards}{Yards gained by the return team.}
 #' \item{penalty_team}{String abbreviation of the team with the penalty.}
@@ -311,7 +319,7 @@
 #' \item{penalty_yards}{Yards gained (or lost) by the posteam from the penalty.}
 #' \item{replay_or_challenge}{Binary indicator for whether or not a replay or challenge.}
 #' \item{replay_or_challenge_result}{String indicating the result of the replay or challenge.}
-#' \item{penalty_type}{String indicating the penalty type.}
+#' \item{penalty_type}{String indicating the penalty type of the first penalty in the given play. Will be `NA` if `desc` is missing the type.}
 #' \item{defensive_two_point_attempt}{Binary indicator whether or not the defense was able to have an attempt on a two point conversion, this results following a turnover.}
 #' \item{defensive_two_point_conv}{Binary indicator whether or not the defense successfully scored on the two point conversion.}
 #' \item{defensive_extra_point_attempt}{Binary indicator whether or not the defense was able to have an attempt on an extra point attempt, this results following a blocked attempt that the defense recovers the ball.}
@@ -442,7 +450,7 @@ fast_scraper <- function(game_ids,
     }, p, ...)
 
     if (length(pbp) != 0) {
-      usethis::ui_done("Download finished. Adding variables...")
+      user_message("Download finished. Adding variables...", "done")
       pbp <- pbp %>%
         add_game_data() %>%
         add_nflscrapr_mutations() %>%
@@ -458,7 +466,8 @@ fast_scraper <- function(game_ids,
   })
 
   if (!in_builder) {
-    usethis::ui_done("{usethis::ui_field('Procedure completed.')}")
+    str <- paste0(my_time(), " | Procedure completed.")
+    usethis::ui_done("{usethis::ui_field(str)}")
   }
   return(pbp)
 }
